<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Tourable Pro
 * @since Tourable Pro 1.0.0
 */
if ( ! function_exists( 'tourable_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Tourable Pro 1.0.0
    */
    function tourable_pro_add_blog_section() {
    	$options = tourable_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'tourable_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'tourable_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        tourable_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'tourable_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Tourable Pro 1.0.0
    * @param array $input blog section details.
    */
    function tourable_pro_get_blog_section_details( $input ) {
        $options = tourable_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_trip_' . $i] ) )
                        $page_ids[] = $options['blog_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['blog_content_trip_types'] ) ? $options['blog_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $blog_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['blog_content_destination'] ) ? $options['blog_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $blog_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['blog_content_activity'] ) ? $options['blog_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $blog_count ),
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = tourable_pro_trim_content( 20 );
                $page_post['author_id'] = get_the_author_meta('ID');
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'tourable_pro_filter_blog_section_details', 'tourable_pro_get_blog_section_details' );


if ( ! function_exists( 'tourable_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Tourable Pro 1.0.0
   *
   */
   function tourable_pro_render_blog_section( $content_details = array() ) {
        $options = tourable_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];
        $readmore = ! empty( $options['blog_read_more'] ) ? $options['blog_read_more'] : esc_html__( 'Read More', 'tourable-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-posts" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                    <?php endif; 

                    if ( ! empty( $options['blog_sub_title'] ) ) : ?>
                        <span class="section-subtitle"><?php echo esc_html( $options['blog_sub_title'] ); ?></span>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content blog-posts-wrapper clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="post-item-wrapper clear">
                                <?php if ( ! empty( $content['image'] ) ) : ?>
                                    <div class="featured-image matchheight" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image -->
                                <?php endif; ?>

                                <div class="entry-container matchheight">
                                    <?php if ( in_array( $options['blog_content_type'], array( 'page', 'post', 'category' ) ) ): ?>  
                                        <div class="entry-meta">
                                            <?php tourable_pro_posted_on( $content['id'] ); ?>
                                        </div><!-- .entry-meta -->
                                    <?php endif ?>
                                    <?php if ( ! in_array( $blog_content_type, array( 'category', 'page', 'post' ) ) ) :
                                    $terms = get_the_terms( $content['id'], 'itinerary_types' ); 
                                    ?>
                                        <?php if ( ! empty( $terms ) ): ?>
                                           <span class="cat-links">
                                                <?php if ( is_array( $terms ) && count( $terms ) > 0 ) : ?>
                                                   <span><?php echo esc_html_e( 'Trip Type : ', 'tourable-pro' ); ?></span>
             
                                                    <div class="wp-travel-caret">
                                                        <div class="sub-category-menu">
                                                            <?php foreach ( $terms as $term ) : ?>
                                                                <?php
                                                                    $term_name = $term->name;
                                                                    $term_link = get_term_link( $term->term_id, 'itinerary_types' ); ?>
                                                                <a href="<?php echo esc_url( $term_link, 'wp-travel' ); ?>">
                                                                    <?php echo esc_html( $term_name ); ?>
                                                                </a>
                                                            <?php endforeach; ?>
                                                        </div>
                                                    </div>
                                                   
                                                <?php endif; ?>
                                            </span> 
                                        <?php endif ?>
                                        
                                    <?php endif; ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                    <?php if ( in_array( $blog_content_type, array( 'category', 'post' ) ) ) : ?>
                                        <div class="entry-meta">
                                            <?php  
                                                tourable_pro_posted_on( $content['id'] );
                                                echo tourable_pro_author_meta( $content['author_id'] );
                                            ?>
                                        </div><!-- .entry-meta -->
                                    <?php endif; ?>
                                    <?php if ( ! in_array( $blog_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                        // if( wp_travel_is_enable_pricing_options( $content['id'] ) ) {
                                        //     $pricing_options = get_post_meta( $content['id'], 'wp_travel_pricing_options', true );
                                        //     $price_key = wp_travel_get_min_price_key( $pricing_options );
                                        // }
                                        $trip_price = WP_Travel_Helpers_Pricings::get_price( array('trip_id'=>$content['id']) );
                                    ?>  
                                        <span class="trip-price">                       
                                            <?php echo wptravel_get_formated_price_currency( $trip_price ); ?>
                                        </span><!-- .trip-price -->
                                    <?php endif; ?>
                                    <?php if ( ! in_array( $blog_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                    $terms = get_the_terms( $content['id'], 'travel_locations' );
                                    ?>
                                        <?php if (  ! empty( $terms ) ): ?>
                                            <div class="entry-meta">
                                                <span>
                                                    <?php echo esc_html_e( 'Location : ', 'tourable-pro' ) ; ?>
                                                </span>
                                                <span>
                                                    <?php foreach ( $terms as $term ) : ?>
                                                        <a href="<?php echo esc_url( get_term_link( $term->term_id, 'travel_locations' ) ); ?>"><?php echo esc_html( $term->name ); ?></a>
                                                    <?php endforeach; ?>
                                                </span>
                                            </div>
                                        <?php endif ?>
                                       
                                    <?php endif; ?>
                                        
                                    <?php if ( 'page' != $blog_content_type ) : 
                                        the_category( '', '', $content['id'] );
                                    endif; ?>

                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link">
                                        <?php  
                                            echo esc_html( $readmore );
                                            echo ' ' . tourable_pro_get_svg( array( 'icon' => 'down' ) );
                                        ?>
                                    </a><!-- .more-link -->
                                </div><!-- .entry-container -->
                            </div><!-- .post-item-wrapper -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->

                <?php if ( ! empty( $options['blog_btn_title'] ) && ! empty( $options['blog_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['blog_btn_url'] ) ?>" class="btn btn-transparent"><?php echo esc_html( $options['blog_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->

    <?php }
endif;